@@ -2,19 +2,19 @@ package Dist::Zilla::Plugin::OurPkgVersion;
 use 5.008;
 use strict;
 use warnings;
-
-our $VERSION = '0.09_01'; # TRIAL VERSION
-
+BEGIN {
+	our $VERSION = '0.003001'; # VERSION
+}
 use Moose;
 with (
 	'Dist::Zilla::Role::FileMunger',
 	'Dist::Zilla::Role::FileFinderUser' => {
 		default_finders => [ ':InstallModules', ':ExecFiles' ],
 	},
-	'Dist::Zilla::Role::PPI',
 );
 
 use PPI;
+use Carp qw(croak);
 use MooseX::Types::Perl qw( LaxVersionStr );
 use namespace::autoclean;
 
@@ -28,35 +28,36 @@ sub munge_files {
 sub munge_file {
 	my ( $self, $file ) = @_;
 
-	if ( $file->name =~ m/\.pod$/ixms ) {
-		$self->log_debug( 'Skipping: "' . $file->name . '" is pod only');
-		return;
-	}
-
 	my $version = $self->zilla->version;
 
-	confess 'invalid characters in version'
+	croak("invalid characters in version")
 		unless LaxVersionStr->check( $version );
 
-	my $doc = $self->ppi_document_for_file($file);
+	my $content = $file->content;
 
-	return unless defined $doc;
+	my $doc = PPI::Document->new(\$content)
+		or croak( 'Error parsing "'
+			. $file->name
+			.  '" with PPI: '
+			. PPI::Document->errstr
+			)
+			;
 
 	my $comments = $doc->find('PPI::Token::Comment');
 
 	my $version_regex
 		= q{
                   ^
-                  (\s*)              # capture all whitespace before comment
+                  (\s*)           # capture all whitespace before comment
                   (
-                    \#\#?\s*VERSION  # capture # VERSION or ## VERSION
-                    \b               # and ensure it ends on a word boundary
-                    [                # conditionally
-                      [:print:]      # all printable characters after VERSION
-                      \s             # any whitespace including newlines - GH #5
-                    ]*               # as many of the above as there are
+                    \#\s+VERSION  # capture # VERSION
+                    \b            # and ensure it ends on a word boundary
+                    [             # conditionally
+                      [:print:]   # all printable characters after VERSION
+                      \s          # any whitespace including newlines see GH #5
+                    ]*            # as many of the above as there are
                   )
-                  $                  # until the EOL}
+                  $               # until the EOL}
 		;
 
 	my $munged_version = 0;
@@ -64,7 +65,6 @@ sub munge_file {
 		foreach ( @{ $comments } ) {
 			if ( /$version_regex/xms ) {
 				my ( $ws, $comment ) =  ( $1, $2 );
-				$comment =~ s/(?=\bVERSION\b)/TRIAL /x if $self->zilla->is_trial;
 				my $code
 						= "$ws"
 						. q{our $VERSION = '}
@@ -72,13 +72,13 @@ sub munge_file {
 						. qq{'; $comment}
 						;
 				$_->set_content("$code");
+				$file->content( $doc->serialize );
 				$munged_version++;
 			}
 		}
 	}
 
 	if ( $munged_version ) {
-		$self->save_ppi_document_to_file( $doc, $file);
 		$self->log_debug([ 'adding $VERSION assignment to %s', $file->name ]);
 	}
 	else {
@@ -91,19 +91,19 @@ sub munge_file {
 }
 __PACKAGE__->meta->make_immutable;
 1;
-# ABSTRACT: No line insertion and does Package version with our
+# ABSTRACT: no line insertion and does Package version with our
+
 
 __END__
-
 =pod
 
 =head1 NAME
 
-Dist::Zilla::Plugin::OurPkgVersion - No line insertion and does Package version with our
+Dist::Zilla::Plugin::OurPkgVersion - no line insertion and does Package version with our
 
 =head1 VERSION
 
-version 0.09_01
+version 0.003001
 
 =head1 SYNOPSIS
 
@@ -188,32 +188,12 @@ becomes
 	our $VERSION = '0.1.0'; # VERSION: generated by DZP::OurPkgVersion
 	...
 
-you can also use perltidy's default static side comments (##)
-
-	...
-	## VERSION
-	...
-
-becomes
-
-	...
-	our $VERSION = '0.1.0'; ## VERSION
-	...
-
 Also note, the package line is not in any way significant, it will insert the
 C<our $VERSION> line anywhere in the file before C<# VERSION> as many times as
 you've written C<# VERSION> regardless of whether or not inserting it there is
 a good idea. OurPkgVersion will not insert a version unless you have C<#
 VERSION> so it is a bit more work.
 
-If you make a trial release, the comment will be altered to say so:
-
-	# VERSION
-
-becomes
-
-	our $VERSION = '0.01'; # TRIAL VERSION
-
 =head1 METHODS
 
 =over
@@ -232,72 +212,23 @@ tells which files to munge, see L<Dist::Zilla::Role::FileMunger>
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://github.com/plicease/dist-zilla-plugin-ourpkgversion/issues
+https://github.com/xenoterracide/Dist-Zilla-Plugin-OurPkgVersion/issues
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 CONTRIBUTORS
-
-=for stopwords Alexandr Ciornii Alexei Znamensky Christian Walde Christopher J. Madsen David Golden Graham Ollis Ian Sealy
-
-=over 4
-
-=item *
-
-Alexandr Ciornii <alexchorny@gmail.com>
-
-=item *
-
-Alexei Znamensky <russoz@cpan.org>
-
-=item *
-
-Christian Walde <walde.christian@googlemail.com>
-
-=item *
-
-Christopher J. Madsen <perl@cjmweb.net>
-
-=item *
-
-David Golden <dagolden@cpan.org>
-
-=item *
-
-Graham Ollis <perl@wdlabs.com>
-
-=item *
-
-Graham Ollis <plicease@cpan.org>
-
-=item *
-
-Ian Sealy <git@iansealy.com>
-
-=back
-
-=head1 AUTHORS
-
-=over 4
-
-=item *
+=head1 AUTHOR
 
 Caleb Cushing <xenoterracide@gmail.com>
 
-=item *
-
-Grahan Ollis <plicease@cpan.org>
-
-=back
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Caleb Cushing.
+This software is Copyright (c) 2012 by Caleb Cushing.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
+
